@@ -1,9 +1,9 @@
 package App::Timestamper;
-$App::Timestamper::VERSION = '0.0.2';
+$App::Timestamper::VERSION = '0.0.3';
 use strict;
 use warnings;
 
-use Getopt::Long qw(2.36 GetOptionsFromArray);
+use Getopt::Long 2.36 qw(GetOptionsFromArray);
 use Pod::Usage qw/pod2usage/;
 
 use App::Timestamper::Filter::TS;
@@ -80,7 +80,7 @@ App::Timestamper - prefix lines with the timestamps of their arrivals.
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
